function [Date1,Open1,High,Low,Close1,Volume,AdjClose] = importAktienkurs(filename, startRow, endRow)
%IMPORTFILE Import numeric data from a text file as column vectors.
%   [DATE1,OPEN1,HIGH,LOW,CLOSE1,VOLUME,ADJCLOSE] = IMPORTFILE(FILENAME)
%   Reads data from text file FILENAME for the default selection.
%
%   [DATE1,OPEN1,HIGH,LOW,CLOSE1,VOLUME,ADJCLOSE] = IMPORTFILE(FILENAME,
%   STARTROW, ENDROW) Reads data from rows STARTROW through ENDROW of text
%   file FILENAME.
%
% Example:
%   [Date1,Open1,High,Low,Close1,Volume,AdjClose] =
%   importfile('amazon.csv',2, 1861);
%
%    See also TEXTSCAN.

% Auto-generated by MATLAB on 2016/02/26 18:24:29

%% Initialize variables.
delimiter = ',';
if nargin<=2
    startRow = 2;
    endRow = inf;
end

%% Format string for each line of text:
%   column1: text (%s)
%	column2: double (%f)
%   column3: double (%f)
%	column4: double (%f)
%   column5: double (%f)
%	column6: double (%f)
%   column7: double (%f)
% For more information, see the TEXTSCAN documentation.
formatSpec = '%s%f%f%f%f%f%f%[^\n\r]';

%% Open the text file.
fileID = fopen(filename,'r');

%% Read columns of data according to format string.
% This call is based on the structure of the file used to generate this
% code. If an error occurs for a different file, try regenerating the code
% from the Import Tool.
dataArray = textscan(fileID, formatSpec, endRow(1)-startRow(1)+1, 'Delimiter', delimiter, 'HeaderLines', startRow(1)-1, 'ReturnOnError', false);
for block=2:length(startRow)
    frewind(fileID);
    dataArrayBlock = textscan(fileID, formatSpec, endRow(block)-startRow(block)+1, 'Delimiter', delimiter, 'HeaderLines', startRow(block)-1, 'ReturnOnError', false);
    for col=1:length(dataArray)
        dataArray{col} = [dataArray{col};dataArrayBlock{col}];
    end
end

%% Close the text file.
fclose(fileID);

%% Post processing for unimportable data.
% No unimportable data rules were applied during the import, so no post
% processing code is included. To generate code which works for
% unimportable data, select unimportable cells in a file and regenerate the
% script.

%% Allocate imported array to column variable names
Date1 = dataArray{:, 1};
Open1 = dataArray{:, 2};
High = dataArray{:, 3};
Low = dataArray{:, 4};
Close1 = dataArray{:, 5};
Volume = dataArray{:, 6};
AdjClose = dataArray{:, 7};


